@@ -5,7 +5,7 @@ use Encode qw(decode);
 use base 'Exporter';
 our @EXPORT = qw(convert_to_ascii);
 our @EXPORT_OK = qw(convert_to_ascii);
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 my %char_map;
 
 =encoding utf8
@@ -369,6 +369,7 @@ __DATA__
 018B 61
 018C 61
 018D 67
+018E 33
 0190 45
 0191 46
 0192 66
@@ -449,10 +450,10 @@ __DATA__
 01E7 67
 01E8 4B
 01E9 6B
-01EA 4F
-01EB 6F
-01EC 4F
-01ED 6F
+01EA 51
+01EB 51
+01EC 51
+01ED 51
 01EE 33
 01EF 33
 01F0 6A
@@ -1054,15 +1055,29 @@ __DATA__
 1803 3A
 1809 3A
 180E 20
-1D04 63
-1D0B 6B
-1D0F 6F
-1D11 6F
-1D1B 74
-1D1C 75
-1D20 76
-1D21 77
-1D22 7A
+1D00 41
+1D01 41+45
+1D03 42
+1D04 43
+1D05 44
+1D07 45
+1D09 21
+1D0A 4A
+1D0B 4B
+1D0C 4C
+1D0D 4D
+1D0E 4E
+1D0F 4F
+1D11 4F
+1D13 4F
+1D18 50
+1D19 52
+1D1A 52
+1D1B 54
+1D1C 55
+1D20 56
+1D21 57
+1D22 5A
 1D26 72
 1D28 6E
 1D2C 41
